Welcome to AutoFLpy's documentation!
======================================

.. include:: ../README.rst


--------------------------

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   examples
   modules
   contributing
   authors
   history